==> cxf-testutils-2.0.6.16-fuse-sources.jar: org/apache/type_test/types2/SequenceWithOccuringGroup.java <==

package org.apache.type_test.types2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SequenceWithOccuringGroup complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SequenceWithOccuringGroup">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;group ref="{http://apache.org/type_test/types2}BatchElementsSeq" maxOccurs="3" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SequenceWithOccuringGroup", propOrder = {
    "batchElementsSeq"
})
public class SequenceWithOccuringGroup {

    @XmlElements({
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types2", required = true, type = String.class),
        @XmlElement(name = "varFloat", namespace = "http://apache.org/type_test/types2", required = true, type = Float.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types2", required = true, type = Integer.class)
    })
    protected List<Serializable> batchElementsSeq;

    /**
     * Gets the value of the batchElementsSeq property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the batchElementsSeq property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBatchElementsSeq().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * {@link Float }
     * {@link Integer }
     * 
     * 
     */
    public List<Serializable> getBatchElementsSeq() {
        if (batchElementsSeq == null) {
            batchElementsSeq = new ArrayList<Serializable>();
        }
        return this.batchElementsSeq;
    }

}

==> cxf-testutils-2.0.12.0-fuse-sources.jar: org/apache/type_test/types2/SequenceWithOccuringGroup.java <==

package org.apache.type_test.types2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SequenceWithOccuringGroup complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SequenceWithOccuringGroup">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;group ref="{http://apache.org/type_test/types2}BatchElementsSeq" maxOccurs="3" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SequenceWithOccuringGroup", propOrder = {
    "batchElementsSeq"
})
public class SequenceWithOccuringGroup {

    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types2", required = true, type = Integer.class),
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types2", required = true, type = String.class),
        @XmlElement(name = "varFloat", namespace = "http://apache.org/type_test/types2", required = true, type = Float.class)
    })
    protected List<Serializable> batchElementsSeq;

    /**
     * Gets the value of the batchElementsSeq property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the batchElementsSeq property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getBatchElementsSeq().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link String }
     * {@link Float }
     * 
     * 
     */
    public List<Serializable> getBatchElementsSeq() {
        if (batchElementsSeq == null) {
            batchElementsSeq = new ArrayList<Serializable>();
        }
        return this.batchElementsSeq;
    }

}
